# Available Nerdfont
Python script to find which [Nerdfonts](https://www.nerdfonts.com/) are 
available for download. This can be particuarly useful for writing automated
download scripts and any analysis on the fonts themselves.

## Requirements
This script can be installed through `pip install available-nerdfont`.

This project officially supports [Python 3.8+](https://www.python.org/).

## Running Instructions
Upon, installation, this script can be run with `available-nerdfont` which will print the results to
the console. Further options can be viewed using `available-nerdfont --help`.
